@@ -1,12 +1,10 @@
 package Test::YAML;
-
-use Test::Base 0.47 -Base;
+use Test::Base 0.45 -Base;
 use lib 'lib';
 
-our $VERSION   = '0.69_02';
-    $VERSION   = eval $VERSION;
-our $YAML    = 'YAML';
-our @EXPORT  = qw(
+our $YAML = 'YAML';
+
+our @EXPORT = qw(
     no_diff
     run_yaml_tests
     run_roundtrip_nyn roundtrip_nyn
@@ -17,12 +15,12 @@ our @EXPORT  = qw(
 
 delimiters('===', '+++');
 
-sub Dump     () { YAML(Dump => @_)     }
-sub Load     () { YAML(Load => @_)     }
-sub DumpFile () { YAML(DumpFile => @_) }
-sub LoadFile () { YAML(LoadFile => @_) }
+sub Dump() { YAML(Dump => @_) }
+sub Load() { YAML(Load => @_) }
+sub DumpFile() { YAML(DumpFile => @_) }
+sub LoadFile() { YAML(LoadFile => @_) }
 
-sub YAML () {
+sub YAML() {
     load_yaml_pm();
     my $meth = shift;
     my $code = $YAML->can($meth) or die "$YAML cannot do $meth";
@@ -183,10 +181,7 @@ sub _skip_test() {
 
 #-------------------------------------------------------------------------------
 package Test::YAML::Filter;
-
-use Test::Base::Filter ();
-
-our @ISA = 'Test::Base::Filter';
+use base 'Test::Base::Filter';
 
 sub yaml_dump {
     Test::YAML::Dump(@_);
@@ -239,33 +234,3 @@ sub _perl_eval_result_error_warning {
     return ($result, $@, $warning);
 }
 
-1;
-
-=head1 NAME
-
-Test::YAML - Testing Module for YAML Implementations
-
-=head1 SYNOPSIS
-
-    use Test::YAML tests => 1;
-
-    pass;
-
-=head1 DESCRIPTION
-
-Test::YAML is a subclass of Test::Base with YAML specific support.
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2006. Ingy döt Net. All rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See L<http://www.perl.com/perl/misc/Artistic.html>
-
-=cut
