@@ -1,30 +1,47 @@
 package YAML::Dumper;
+use YAML::Dumper::Base -Base;
 
-use strict;
-use warnings;
-use YAML::Base;
-use YAML::Dumper::Base;
 use YAML::Node;
 use YAML::Types;
 
-our $VERSION   = '0.69_02';
-    $VERSION   = eval $VERSION;
-our @ISA     = 'YAML::Dumper::Base';
-
 # Context constants
-use constant KEY       => 3;
-use constant BLESSED   => 4;
+use constant KEY => 3;
+use constant BLESSED => 4;
 use constant FROMARRAY => 5;
-use constant VALUE     => "\x07YAML\x07VALUE\x07";
+use constant VALUE => "\x07YAML\x07VALUE\x07";
 
 # Common YAML character sets
 my $ESCAPE_CHAR = '[\\x00-\\x08\\x0b-\\x0d\\x0e-\\x1f]';
-my $LIT_CHAR    = '|';    
+my $FOLD_CHAR = '>';
+my $LIT_CHAR = '|';    
 
 #==============================================================================
+# Save the contents of a Dump operation to a file. If the file exists
+# and has data, and a concatenation was requested, then verify the
+# existing header.
+sub DumpFile {
+    my $filename = shift;
+    local $/ = "\n"; # reset special to "sane"
+    my $mode = '>';
+    if ($filename =~ /^\s*(>{1,2})\s*(.*)$/) {
+        ($mode, $filename) = ($1, $2);
+    }
+    if ($mode eq '>>' && -f $filename && -s $filename) {
+        open MYYAML, "< $filename" 
+            or $self->die('YAML_LOAD_ERR_FILE_INPUT', $filename, $!);
+        my $line = <MYYAML>;
+        close MYYAML;
+        $self->die('YAML_DUMP_ERR_FILE_CONCATENATE', $filename)
+          unless $line =~ /^---(\s|$)/;
+    }
+    open MYYAML, "$mode $filename"
+      or $self->die('YAML_DUMP_ERR_FILE_OUTPUT', $filename, $!);
+    print MYYAML YAML::Dump(@_);
+    close MYYAML;
+}
+    
 # OO version of Dump. YAML->new->dump($foo); 
 sub dump {
-    my $self = shift;
     $self->stream('');
     $self->document(0);
     for my $document (@_) {
@@ -45,7 +62,6 @@ sub dump {
 # Every YAML document in the stream must begin with a YAML header, unless
 # there is only a single document and the user requests "no header".
 sub _emit_header {
-    my $self = shift;
     my ($node) = @_;
     if (not $self->use_header and 
         $self->document == 1
@@ -71,7 +87,6 @@ sub _emit_header {
 # This function is where the Dumper does all its work. All type
 # transfers happen here.
 sub _prewalk {
-    my $self = shift;
     my $stringify = $self->stringify;
     my ($class, $type, $node_id) = $self->node_info(\$_[0], $stringify);
 
@@ -85,6 +100,8 @@ sub _prewalk {
 
     # Handle regexps
     if (ref($_[0]) eq 'Regexp') {  
+        $self->transferred->{$node_id} =
+          YAML::Type::regexp->yaml_dump($_[0], $class, $self);
         return;
     }
 
@@ -209,15 +226,9 @@ value: $value
 # Every data element and sub data element is a node.
 # Everything emitted goes through this function.
 sub _emit_node {
-    my $self = shift;
     my ($type, $node_id);
     my $ref = ref($_[0]);
-    if ($ref) {
-        if ($ref eq 'Regexp') {
-            $self->_emit(' !!perl/regexp');
-            $self->_emit_str("$_[0]");
-            return;
-        }
+    if ($ref and $ref ne 'Regexp') {
         (undef, $type, $node_id) = $self->node_info($_[0], $self->stringify);
     }
     else {
@@ -237,8 +248,7 @@ sub _emit_node {
               $self->node_info($value, $self->stringify);
         }
         else {
-            $ynode = ynode($self->transferred->{$node_id});
-            $tag = defined $ynode ? $ynode->tag->short : '';
+            $tag = ynode($self->transferred->{$node_id})->tag->short;
             $type = 'SCALAR';
             (undef, undef, $node_id) = 
               $self->node_info(
@@ -280,7 +290,6 @@ sub _emit_node {
 
 # A YAML mapping is akin to a Perl hash. 
 sub _emit_mapping {
-    my $self = shift;
     my ($value, $tag, $node_id, $context) = @_;
     $self->{stream} .= " !$tag" if $tag;
 
@@ -354,7 +363,6 @@ sub _emit_mapping {
 
 # A YAML series is akin to a Perl array.
 sub _emit_sequence {
-    my $self = shift;
     my ($value, $tag) = @_;
     $self->{stream} .= " !$tag" if $tag;
 
@@ -392,7 +400,6 @@ sub _emit_sequence {
 
 # Emit a mapping key
 sub _emit_key {
-    my $self = shift;
     my ($value, $context) = @_;
     $self->{stream} .= ' ' x $self->offset->[$self->level]
       unless $context == FROMARRAY;
@@ -401,21 +408,18 @@ sub _emit_key {
 
 # Emit a blessed SCALAR
 sub _emit_scalar {
-    my $self = shift;
     my ($value, $tag) = @_;
     $self->{stream} .= " !$tag";
     $self->_emit_str($value, BLESSED);
 }
 
 sub _emit {
-    my $self = shift;
     $self->{stream} .= join '', @_;
 }
 
 # Emit a string value. YAML has many scalar styles. This routine attempts to
 # guess the best style for the text.
 sub _emit_str {
-    my $self = shift;
     my $type = $_[1] || 0;
 
     # Use heuristics to find the best scalar emission style.
@@ -444,12 +448,18 @@ sub _emit_str {
             $self->_emit_block($LIT_CHAR, $_[0]),
             $self->_emit($eb), last
               if $self->use_block;
-              Carp::cluck "[YAML] \$UseFold is no longer supported"
+            $self->_emit($sb),
+            $self->_emit_block($FOLD_CHAR, $_[0]),
+            $self->_emit($eb), last
               if $self->use_fold;
             $self->_emit($sf),
             $self->_emit_double($_[0]),
             $self->_emit($ef), last
               if length $_[0] <= 30;
+            $self->_emit($sb),
+            $self->_emit_block($FOLD_CHAR, $_[0]),
+            $self->_emit($eb), last
+              if $_[0] =~ /^\S[^\n]{76}/m;
             $self->_emit($sf),
             $self->_emit_double($_[0]),
             $self->_emit($ef), last
@@ -479,7 +489,6 @@ sub _emit_str {
 
 # Check whether or not a scalar should be emitted as an plain scalar.
 sub is_valid_plain {
-    my $self = shift;
     return 0 unless length $_[0];
     # refer to YAML::Loader::parse_inline_simple()
     return 0 if $_[0] =~ /^[\s\{\[\~\`\'\"\!\@\#\>\|\%\&\?\*\^]/;
@@ -491,8 +500,8 @@ sub is_valid_plain {
     return 1;
 }
 
+# A nested scalar is either block or folded 
 sub _emit_block {
-    my $self = shift;
     my ($indicator, $value) = @_;
     $self->{stream} .= $indicator;
     $value =~ /(\n*)\Z/;
@@ -500,25 +509,26 @@ sub _emit_block {
     $value = '~' if not defined $value;
     $self->{stream} .= $chomp;
     $self->{stream} .= $self->indent_width if $value =~ /^\s/;
+    if ($indicator eq $FOLD_CHAR) {
+        $value = $self->fold($value);
+        chop $value unless $chomp eq '+';
+    }
     $self->{stream} .= $self->indent($value);
 }
 
 # Plain means that the scalar is unquoted.
 sub _emit_plain {
-    my $self = shift;
     $self->{stream} .= defined $_[0] ? $_[0] : '~';
 }
 
 # Double quoting is for single lined escaped strings.
 sub _emit_double {
-    my $self = shift;
     (my $escaped = $self->escape($_[0])) =~ s/"/\\"/g;
     $self->{stream} .= qq{"$escaped"};
 }
 
 # Single quoting is for single lined unescaped strings.
 sub _emit_single {
-    my $self = shift;
     my $item = shift;
     $item =~ s{'}{''}g;
     $self->{stream} .= "'$item'";
@@ -530,7 +540,6 @@ sub _emit_single {
 
 # Indent a scalar to the current indentation level.
 sub indent {
-    my $self = shift;
     my ($text) = @_;
     return $text unless length $text;
     $text =~ s/\n\Z//;
@@ -540,8 +549,29 @@ sub indent {
     return $text;
 }
 
+# Fold a paragraph to fit within a certain columnar restraint.
+sub fold {
+    my ($text) = @_;
+    my $folded = '';
+    $text =~ s/^(\S.*)\n(?=\S)/$1\n\n/gm;
+    while (length $text > 0) {
+        if ($text =~ s/^([^\n]{0,76})(\n|\Z)//) {
+            $folded .= $1;
+        }
+        elsif ($text =~ s/^(.{0,76})\s//) { 
+            $folded .= $1;
+        }
+        else {
+            $self->die("bad news") unless $text =~ s/(.*?)(\s|\Z)//;
+            $folded .= $1;
+        }
+        $folded .= "\n";
+    }
+    return $folded;
+}
+
 # Escapes for unprintable characters
-my @escapes = qw(\0   \x01 \x02 \x03 \x04 \x05 \x06 \a
+my @escapes = qw(\z   \x01 \x02 \x03 \x04 \x05 \x06 \a
                  \x08 \t   \n   \v   \f   \r   \x0e \x0f
                  \x10 \x11 \x12 \x13 \x14 \x15 \x16 \x17
                  \x18 \x19 \x1a \e   \x1c \x1d \x1e \x1f
@@ -549,15 +579,12 @@ my @escapes = qw(\0   \x01 \x02 \x03 \x04 \x05 \x06 \a
 
 # Escape the unprintable characters
 sub escape {
-    my $self = shift;
     my ($text) = @_;
     $text =~ s/\\/\\\\/g;
     $text =~ s/([\x00-\x1f])/$escapes[ord($1)]/ge;
     return $text;
 }
 
-1;
-
 __END__
 
 =head1 NAME
