@@ -1,47 +1,36 @@
 package YAML::Dumper::Base;
-
-use strict;
-use warnings;
-use YAML::Base;
+use YAML::Base -Base;
 use YAML::Node;
 
-our $VERSION   = '0.69_02';
-    $VERSION   = eval $VERSION;
-our @ISA     = 'YAML::Base';
-
 # YAML Dumping options
-field spec_version    => '1.0';
-field indent_width    => 2;
-field use_header      => 1;
-field use_version     => 0;
-field sort_keys       => 1;
-field anchor_prefix   => '';
-field dump_code       => 0;
-field use_block       => 0;
-field use_fold        => 0;
+field spec_version => '1.0';
+field indent_width => 2;
+field use_header => 1;
+field use_version => 0;
+field sort_keys => 1;
+field anchor_prefix => '';
+field dump_code => 0;
+field use_block => 0;
+field use_fold => 0;
 field compress_series => 1;
-field inline_series   => 0;
-field use_aliases     => 1;
-field purity          => 0;
-field stringify       => 0;
+field inline_series => 0;
+field use_aliases => 1;
+field purity => 0;
+field stringify => 0;
 
 # Properties
-field stream      => '';
-field document    => 0;
+field stream => '';
+field document => 0;
 field transferred => {};
-field id_refcnt   => {};
-field id_anchor   => {};
-field anchor      => 1;
-field level       => 0;
-field offset      => [];
-field headless    => 0;
+field id_refcnt => {};
+field id_anchor => {};
+field anchor => 1;
+field level => 0;
+field offset => [];
+field headless => 0;
 field blessed_map => {};
 
-# Global Options are an idea taken from Data::Dumper. Really they are just
-# sugar on top of real OO properties. They make the simple Dump/Load API
-# easy to configure.
 sub set_global_options {
-    my $self = shift;
     $self->spec_version($YAML::SpecVersion)
       if defined $YAML::SpecVersion;
     $self->indent_width($YAML::Indent)
@@ -73,12 +62,10 @@ sub set_global_options {
 }
 
 sub dump {
-    my $self = shift;
     $self->die('dump() not implemented in this class.');
 }
 
 sub blessed {
-    my $self = shift;
     my ($ref) = @_;
     $ref = \$_[0] unless ref $ref;
     my (undef, undef, $node_id) = YAML::Base->node_info($ref);
@@ -86,7 +73,6 @@ sub blessed {
 }
     
 sub bless {
-    my $self = shift;
     my ($ref, $blessing) = @_;
     my $ynode;
     $ref = \$_[0] unless ref $ref;
@@ -110,8 +96,6 @@ sub bless {
     return $object;
 }
 
-1;
-
 __END__
 
 =head1 NAME
