@@ -1,12 +1,5 @@
 package YAML::Error;
-
-use strict;
-use warnings;
-use YAML::Base;
-
-our $VERSION   = '0.69_02';
-    $VERSION   = eval $VERSION;
-our @ISA     = 'YAML::Base';
+use YAML::Base -Base;
 
 field 'code';
 field 'type' => 'Error';
@@ -17,7 +10,6 @@ field 'arguments' => [];
 my ($error_messages, %line_adjust);
 
 sub format_message {
-    my $self = shift;
     my $output = 'YAML ' . $self->type . ': ';
     my $code = $self->code;
     if ($error_messages->{$code}) {
@@ -191,10 +183,7 @@ YAML_LOAD_WARN_GLOB_IO
     );
 
 package YAML::Warning;
-
-our @ISA = 'YAML::Error';
-
-1;
+use base 'YAML::Error';
 
 __END__
 
