@@ -1,29 +1,20 @@
 package YAML::Loader;
-
-use strict;
-use warnings;
-use YAML::Base;
-use YAML::Loader::Base;
+use YAML::Loader::Base -Base;
 use YAML::Types;
 
-our $VERSION   = '0.69_02';
-    $VERSION   = eval $VERSION;
-our @ISA     = 'YAML::Loader::Base';
-
 # Context constants
-use constant LEAF       => 1;
+use constant LEAF => 1;
 use constant COLLECTION => 2;
-use constant VALUE      => "\x07YAML\x07VALUE\x07";
-use constant COMMENT    => "\x07YAML\x07COMMENT\x07";
+use constant VALUE => "\x07YAML\x07VALUE\x07";
+use constant COMMENT => "\x07YAML\x07COMMENT\x07";
 
 # Common YAML character sets
 my $ESCAPE_CHAR = '[\\x00-\\x08\\x0b-\\x0d\\x0e-\\x1f]';
-my $FOLD_CHAR   = '>';
-my $LIT_CHAR    = '|';    
+my $FOLD_CHAR = '>';
+my $LIT_CHAR = '|';    
 my $LIT_CHAR_RX = "\\$LIT_CHAR";    
 
 sub load {
-    my $self = shift;
     $self->stream($_[0] || '');
     return $self->_parse();
 }
@@ -31,7 +22,6 @@ sub load {
 # Top level function for parsing. Parse each document in order and
 # handle processing for YAML headers.
 sub _parse {
-    my $self = shift;
     my (%directives, $preface);
     $self->{stream} =~ s|\015\012|\012|g;
     $self->{stream} =~ s|\015|\012|g;
@@ -112,7 +102,6 @@ sub _parse {
 # recurses back through here. (Inlines are an exception as they have
 # their own sub-parser.)
 sub _parse_node {
-    my $self = shift;
     my $preface = $self->preface;
     $self->preface('');
     my ($node, $type, $indicator, $escape, $chomp) = ('') x 5;
@@ -217,7 +206,6 @@ sub _parse_node {
 
 # Preprocess the qualifiers that may be attached to any node.
 sub _parse_qualifiers {
-    my $self = shift;
     my ($preface) = @_;
     my ($anchor, $alias, $explicit, $implicit, $token) = ('') x 5;
     $self->inline('');
@@ -253,34 +241,9 @@ sub _parse_qualifiers {
 
 # Morph a node to it's explicit type  
 sub _parse_explicit {
-    my $self = shift;
     my ($node, $explicit) = @_;
     my ($type, $class);
-    if ($explicit =~ /^\!?perl\/(hash|array|ref|scalar)(?:\:(\w(\w|\:\:)*)?)?$/) {
-        ($type, $class) = (($1 || ''), ($2 || ''));
-
-        # FIXME # die unless uc($type) eq ref($node) ?
-
-        if ( $type eq "ref" ) {
-            $self->die('YAML_LOAD_ERR_NO_DEFAULT_VALUE', 'XXX', $explicit)
-            unless exists $node->{VALUE()} and scalar(keys %$node) == 1;
-
-            my $value = $node->{VALUE()};
-            $node = \$value;
-        }
-        
-        if ( $type eq "scalar" and length($class) and !ref($node) ) {
-            my $value = $node;
-            $node = \$value;
-        }
-
-        if ( length($class) ) {
-            CORE::bless($node, $class);
-        }
-
-        return $node;
-    }
-    if ($explicit =~ m{^!?perl/(glob|regexp|code)(?:\:(\w(\w|\:\:)*)?)?$}) {
+    if ($explicit =~ /^perl\/(undef|glob|regexp|code|ref)\:(\w(\w|\:\:)*)?$/) {
         ($type, $class) = (($1 || ''), ($2 || ''));
         my $type_class = "YAML::Type::$type";
         no strict 'refs';
@@ -291,7 +254,6 @@ sub _parse_explicit {
             $self->die('YAML_LOAD_ERR_NO_CONVERT', 'XXX', $explicit);
         }
     }
-    # This !perl/@Foo and !perl/$Foo are deprecated but still parsed
     elsif ($YAML::TagClass->{$explicit} ||
            $explicit =~ m{^perl/(\@|\$)?([a-zA-Z](\w|::)+)$}
           ) {
@@ -322,7 +284,6 @@ sub _parse_explicit {
 
 # Parse a YAML mapping into a Perl hash
 sub _parse_mapping {
-    my $self = shift;
     my ($anchor) = @_;
     my $mapping = {};
     $self->anchor2node->{$anchor} = $mapping;
@@ -371,7 +332,6 @@ sub _parse_mapping {
 
 # Parse a YAML sequence into a Perl array
 sub _parse_seq {
-    my $self = shift;
     my ($anchor) = @_;
     my $seq = [];
     $self->anchor2node->{$anchor} = $seq;
@@ -403,7 +363,6 @@ sub _parse_seq {
 # Parse an inline value. Since YAML supports inline collections, this is
 # the top level of a sub parsing.
 sub _parse_inline {
-    my $self = shift;
     my ($top, $top_implicit, $top_explicit) = (@_, '', '', '');
     $self->{inline} =~ s/^\s*(.*)\s*$/$1/; # OUCH - mugwump
     my ($node, $anchor, $alias, $explicit, $implicit) = ('') x 5;
@@ -469,7 +428,6 @@ sub _parse_inline {
 
 # Parse the inline YAML mapping into a Perl hash
 sub _parse_inline_mapping {
-    my $self = shift;
     my ($anchor) = @_;
     my $node = {};
     $self->anchor2node->{$anchor} = $node;
@@ -496,7 +454,6 @@ sub _parse_inline_mapping {
 
 # Parse the inline YAML sequence into a Perl array
 sub _parse_inline_seq {
-    my $self = shift;
     my ($anchor) = @_;
     my $node = [];
     $self->anchor2node->{$anchor} = $node;
@@ -515,7 +472,6 @@ sub _parse_inline_seq {
 
 # Parse the inline double quoted string.
 sub _parse_inline_double_quoted {
-    my $self = shift;
     my $node;
     if ($self->inline =~ /^"((?:\\"|[^"])*)"\s*(.*)$/) {
         $node = $1;
@@ -531,7 +487,6 @@ sub _parse_inline_double_quoted {
 
 # Parse the inline single quoted string.
 sub _parse_inline_single_quoted {
-    my $self = shift;
     my $node;
     if ($self->inline =~ /^'((?:''|[^'])*)'\s*(.*)$/) {
         $node = $1;
@@ -546,7 +501,6 @@ sub _parse_inline_single_quoted {
 
 # Parse the inline unquoted string and do implicit typing.
 sub _parse_inline_simple {
-    my $self = shift;
     my $value;
     if ($self->inline =~ /^(|[^!@#%^&*].*?)(?=[\[\]\{\},]|, |: |- |:\s*$|$)/) {
         $value = $1;
@@ -559,7 +513,6 @@ sub _parse_inline_simple {
 }
 
 sub _parse_implicit {
-    my $self = shift;
     my ($value) = @_;
     $value =~ s/\s*$//;
     return $value if $value eq '';
@@ -572,7 +525,6 @@ sub _parse_implicit {
 
 # Unfold a YAML multiline scalar into a single string.
 sub _parse_unfold {
-    my $self = shift;
     my ($chomp) = @_;
     my $node = '';
     my $space = 0;
@@ -589,7 +541,6 @@ sub _parse_unfold {
 
 # Parse a YAML block style scalar. This is like a Perl here-document.
 sub _parse_block {
-    my $self = shift;
     my ($chomp) = @_;
     my $node = '';
     while (not $self->done and $self->indent == $self->offset->[$self->level]) {
@@ -605,7 +556,6 @@ sub _parse_block {
 # Handle Perl style '#' comments. Comments must be at the same indentation
 # level as the collection line following them.
 sub _parse_throwaway_comments {
-    my $self = shift;
     while (@{$self->lines} and
            $self->lines->[0] =~ m{^\s*(\#|$)}
           ) {
@@ -626,7 +576,6 @@ sub _parse_throwaway_comments {
 #   B) Set $self->indent, $self->content, $self->line
 # 4) Expand tabs appropriately  
 sub _parse_next_line {
-    my $self = shift;
     my ($type) = @_;
     my $level = $self->level;
     my $offset = $self->offset->[$level];
@@ -733,29 +682,21 @@ sub _parse_next_line {
 #==============================================================================
 
 # Printable characters for escapes
-my %unescapes = (
-   0 => "\x00",
-   a => "\x07",
-   t => "\x09",
-   n => "\x0a",
-   'v' => "\x0b", # Potential v-string error on 5.6.2 if not quoted
-   f => "\x0c",
-   r => "\x0d",
-   e => "\x1b",
-   '\\' => '\\',
+my %unescapes = 
+  (
+   z => "\x00", a => "\x07", t => "\x09",
+   n => "\x0a", v => "\x0b", f => "\x0c",
+   r => "\x0d", e => "\x1b", '\\' => '\\',
   );
    
 # Transform all the backslash style escape characters to their literal meaning
 sub _unescape {
-    my $self = shift;
     my ($node) = @_;
-    $node =~ s/\\([never\\fart0]|x([0-9a-fA-F]{2}))/
+    $node =~ s/\\([never\\fartz]|x([0-9a-fA-F]{2}))/
               (length($1)>1)?pack("H2",$2):$unescapes{$1}/gex;
     return $node;
 }
 
-1;
-
 __END__
 
 =head1 NAME
