@@ -1,36 +1,28 @@
 package YAML::Marshall;
+use Spiffy -Base;
+use YAML::Node();
 
-use strict;
-use warnings;
-use YAML::Node ();
-
-our $VERSION   = '0.69_02';
-    $VERSION   = eval $VERSION;
-
-sub import {
-    my $class = shift;
-    no strict 'refs';
-    my $package = caller;
-    unless (grep { $_ eq $class} @{$package . '::ISA'}) {
-        push @{$package . '::ISA'}, $class;
-    }
-
-    my $tag = shift;
-    if ( $tag ) {
+sub import() {
+    my ($package, $mixin, $tag) = @_;
+    if ($mixin eq '-mixin' && $tag) {
+        my $class = caller;
         no warnings 'once';
-        $YAML::TagClass->{$tag} = $package;
-        ${$package . "::YamlTag"} = $tag;
+        $YAML::TagClass->{$tag} = $class;
+        no strict 'refs';
+        ${$class . "::YamlTag"} = $tag;
+        pop @_;
     }
+
+    goto &Spiffy::import;
 }
 
 sub yaml_dump {
-    my $self = shift;
     no strict 'refs';
     my $tag = ${ref($self) . "::YamlTag"} || 'perl/' . ref($self);
     $self->yaml_node($self, $tag);
 }
 
-sub yaml_load {
+sub yaml_load() {
     my ($class, $node) = @_;
     if (my $ynode = $class->yaml_ynode($node)) {
         $node = $ynode->{NODE};
@@ -39,17 +31,13 @@ sub yaml_load {
 }
 
 sub yaml_node {
-    shift;
     YAML::Node->new(@_);
 }
 
 sub yaml_ynode {
-    shift;
     YAML::Node::ynode(@_);
 }
 
-1;
-
 __END__
 
 =head1 NAME
