@@ -1,59 +1,38 @@
 package YAML::Types;
-
-use strict;
-use warnings;
-use YAML::Base;
+use YAML::Base -Base;
 use YAML::Node;
 
-our $VERSION   = '0.69_02';
-    $VERSION   = eval $VERSION;
-our @ISA     = 'YAML::Base';
-
 # XXX These classes and their APIs could still use some refactoring,
 # but at least they work for now.
 #-------------------------------------------------------------------------------
 package YAML::Type::blessed;
-
-use YAML::Base; # XXX
-
+my %sigil = (HASH => '', ARRAY => '@', SCALAR => '$');
 sub yaml_dump {
-    my $self = shift;
     my ($value) = @_;
     my ($class, $type) = YAML::Base->node_info($value);
     no strict 'refs';
-    my $kind = lc($type) . ':';
     my $tag = ${$class . '::ClassTag'} ||
-              "!perl/$kind$class";
-    if ($type eq 'REF') {
-        YAML::Node->new(
-            {(&YAML::VALUE, ${$_[0]})}, $tag
-        );
-    }
-    elsif ($type eq 'SCALAR') {
+              "perl/$sigil{$type}$class";
+    if ($type eq 'SCALAR') {
         $_[1] = $$value;
-        YAML::Node->new($_[1], $tag);
+        YAML::Node->new($_[1], $tag)
     } else {
-        YAML::Node->new($value, $tag);
+        YAML::Node->new($value, $tag)
     }
 }
 
 #-------------------------------------------------------------------------------
 package YAML::Type::undef;
-
 sub yaml_dump {
-    my $self = shift;
 }
 
 sub yaml_load {
-    my $self = shift;
 }
 
 #-------------------------------------------------------------------------------
 package YAML::Type::glob;
-
 sub yaml_dump {
-    my $self = shift;
-    my $ynode = YAML::Node->new({}, '!perl/glob:');
+    my $ynode = YAML::Node->new({}, 'perl/glob:');
     for my $type (qw(PACKAGE NAME SCALAR ARRAY HASH CODE IO)) {
         my $value = *{$_[0]}{$type};
         $value = $$value if $type eq 'SCALAR';
@@ -77,7 +56,6 @@ sub yaml_dump {
 }
 
 sub yaml_load {
-    my $self = shift;
     my ($node, $class, $loader) = @_;
     my ($name, $package);
     if (defined $node->{NAME}) {
@@ -119,17 +97,14 @@ sub yaml_load {
 
 #-------------------------------------------------------------------------------
 package YAML::Type::code;
-
 my $dummy_warned = 0; 
 my $default = '{ "DUMMY" }';
-
 sub yaml_dump {
-    my $self = shift;
     my $code;
     my ($dumpflag, $value) = @_;
     my ($class, $type) = YAML::Base->node_info($value);
-    my $tag = "!perl/code";
-    $tag .= ":$class" if defined $class;
+    $class ||= '';
+    my $tag = "perl/code:$class";
     if (not $dumpflag) {
         $code = $default;
     }
@@ -155,7 +130,6 @@ sub yaml_dump {
 }    
 
 sub yaml_load {
-    my $self = shift;
     my ($node, $class, $loader) = @_;
     if ($loader->load_code) {
         my $code = eval "package main; sub $node";
@@ -169,21 +143,17 @@ sub yaml_load {
         }
     }
     else {
-        return CORE::bless sub {}, $class if $class;
         return sub {};
     }
 }
 
 #-------------------------------------------------------------------------------
 package YAML::Type::ref;
-
 sub yaml_dump {
-    my $self = shift;
-    YAML::Node->new({(&YAML::VALUE, ${$_[0]})}, '!perl/ref')
+    YAML::Node->new({(&YAML::VALUE, ${$_[0]})}, 'perl/ref:')
 }
 
 sub yaml_load {
-    my $self = shift;
     my ($node, $class, $loader) = @_;
     $loader->die('YAML_LOAD_ERR_NO_DEFAULT_VALUE', 'ptr')
       unless exists $node->{&YAML::VALUE};
@@ -192,50 +162,56 @@ sub yaml_load {
 
 #-------------------------------------------------------------------------------
 package YAML::Type::regexp;
-
 # XXX Be sure to handle blessed regexps (if possible)
 sub yaml_dump {
-    die "YAML::Type::regexp::yaml_dump not currently implemented";
+    my ($node, $class, $dumper) = @_;
+    my ($regexp, $modifiers);
+    if ("$node" =~ /^\(\?(\w*)(?:\-\w+)?\:(.*)\)$/) {
+        $regexp = $2;
+        $modifiers = $1 || '';
+    }
+    else {
+        $dumper->die('YAML_DUMP_ERR_BAD_REGEXP', $node);
+    }
+    my $tag = 'perl/regexp:';
+    $tag .= $class if $class;
+    my $ynode = YAML::Node->new({}, $tag);
+    $ynode->{REGEXP} = $regexp; 
+    $ynode->{MODIFIERS} = $modifiers if $modifiers; 
+    return $ynode;
 }
 
-use constant _QR_TYPES => {
-    '' => sub { qr{$_[0]} },
-    x => sub { qr{$_[0]}x },
-    i => sub { qr{$_[0]}i },
-    s => sub { qr{$_[0]}s },
-    m => sub { qr{$_[0]}m },
-    ix => sub { qr{$_[0]}ix },
-    sx => sub { qr{$_[0]}sx },
-    mx => sub { qr{$_[0]}mx },
-    si => sub { qr{$_[0]}si },
-    mi => sub { qr{$_[0]}mi },
-    ms => sub { qr{$_[0]}sm },
-    six => sub { qr{$_[0]}six },
-    mix => sub { qr{$_[0]}mix },
-    msx => sub { qr{$_[0]}msx },
-    msi => sub { qr{$_[0]}msi },
-    msix => sub { qr{$_[0]}msix },
-};
-
 sub yaml_load {
-    my $self = shift;
-    my ($node, $class) = @_;
-    return qr{$node} unless $node =~ /^\(\?([\-xism]*):(.*)\)\z/s;
-    my ($flags, $re) = ($1, $2);
-    $flags =~ s/-.*//;
-    my $sub = _QR_TYPES->{$flags} || sub { qr{$_[0]} };
-    my $qr = &$sub($re);
-    bless $qr, $class if length $class;
-    return $qr;
+    my ($node, $class, $loader) = @_;
+    my ($regexp, $modifiers);
+    if (defined $node->{REGEXP}) {
+        $regexp = $node->{REGEXP};
+        delete $node->{REGEXP};
+    }
+    else {
+        $loader->warn('YAML_LOAD_WARN_NO_REGEXP_IN_REGEXP');
+        return undef;
+    }
+    if (defined $node->{MODIFIERS}) {
+        $modifiers = $node->{MODIFIERS};
+        delete $node->{MODIFIERS};
+    }
+    else {
+        $modifiers = '';
+    }
+    for my $elem (sort keys %$node) {
+        $loader->warn('YAML_LOAD_WARN_BAD_REGEXP_ELEM', $elem);
+    }
+    my $qr = $regexp;
+    $qr = "(?$modifiers:$qr)";
+    return qr{$qr};
 }
 
-1;
-
 __END__
 
 =head1 NAME
 
-YAML::Types - Marshall Perl internal data types to/from YAML
+YAML::Transfer - Marshall Perl internal data types to/from YAML
 
 =head1 SYNOPSIS
 
